@@ -453,18 +453,30 @@ pub mod macros {
             slice_func(vec, start, stop)
         };};
     }
-    pub fn run() {
-        let v1 = slice_vec!(vec![1.2, 1.5, 9.0], [..2]);
-        let v2 = slice_vec!(vec![1, 1, 9, 90, 87, 0, 2], [4..6]);
-        let v3 = slice_vec!(vec![1.2, 1.5, 9.0], [..]);
-        let v4 = slice_vec!(vec![1.2, 1.5, 9.0], [1..]);
-        let v5 = slice_vec!(vec!["1", "2", "3", "4", "5"], [2..5]);
-        assert_eq!(v1, vec![1.2, 1.5]);
-        assert_eq!(v2, vec![87, 0]);
-        assert_eq!(v3, vec![1.2, 1.5, 9.0]);
-        assert_eq!(v4, vec![1.5, 9.0]);
-        assert_eq!(v5, vec!["3", "4", "5"]);
+
+    /// vec_element_clone!() used to when occure
+    /// cannot move out of index of `Vec<String>`
+    /// move occurs because value has type `String`, which does not implement the `Copy` trait
+    /// ```rust
+    ///let v1 = vec_element_clone!(vec!["15.", "2.9"], 1);
+    ///let v2 = vec_element_clone!(vec![15, 2, 3, 2], 2);
+    ///let v3 = vec_element_clone!(vec![0.15, 0.2, 0.2], 0);
+    ///let v4 = vec_element_clone!(vec![format!("1"),format!("2"),format!("3"),format!("4"),format!("5")],4);
+    ///assert_eq!("2.9", v1);
+    ///assert_eq!(3, v2);
+    ///assert_eq!(0.15, v3);
+    ///assert_eq!(format!("5"), v4);
+    /// ```
+    #[macro_export]
+    macro_rules! vec_element_clone {
+        ($vec:expr,$index:expr) => {{
+            let mut vec = $vec.clone();
+            let s = &vec[$index];
+            s.to_owned()
+        };};
     }
+
+    pub fn run() {}
 }
 
 #[cfg(test)]
